@@ -2,13 +2,13 @@ package Log::Any::App;
 
 # i need this to run on centos 5.x. otherwise all my other servers are debian
 # 5.x and 6.x+ (perl 5.010).
-use 5.008;
+use 5.008000;
 use strict;
 use warnings;
 
 use File::Path qw(make_path);
 use File::Spec;
-use Log::Any 0.11;
+use Log::Any 0.14;
 use Log::Any::Adapter;
 
 our $VERSION = 0.43; # xVERSION
@@ -58,7 +58,13 @@ sub init {
     $caller ||= caller();
 
     my $spec = _parse_opts($args, $caller);
-    _init_log4perl($spec) if $spec->{log} && $spec->{init};
+    if ($spec->{log} && $spec->{init}) {
+        _init_log4perl($spec);
+        if ($ENV{LOG_ENV}) {
+           my $log_main = Log::Any->get_logger(category => 'main');
+           $log_main->tracef("Environment variables: %s", \%ENV);
+       }
+    }
     $spec;
 }
 
@@ -890,8 +896,8 @@ sub import {
 1;
 # ABSTRACT: An easy way to use Log::Any in applications
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -900,7 +906,7 @@ Log::Any::App - An easy way to use Log::Any in applications
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -1620,11 +1626,11 @@ If you have a favorite pattern style, please do share them.
 
 Below is summary of environment variables used.
 
-Turning on/off logging:
+=head2 Turning on/off logging
 
  LOG (bool)
 
-For setting general level:
+=head2 Setting general level
 
  TRACE (bool)       setting general level to trace
  DEBUG (bool)       setting general level to debug
@@ -1632,41 +1638,55 @@ For setting general level:
  QUIET (bool)       setting general level to error (turn off warnings)
  LOG_LEVEL (str)
 
-Setting per-output level:
+=head2 Setting per-output level
 
  FILE_TRACE, FILE_DEBUG, FILE_VERBOSE, FILE_QUIET, FILE_LOG_LEVEL
  SCREEN_TRACE and so on
  DIR_TRACE and so on
  SYSLOG_TRACE and so on
 
-Setting per-category level:
+=head2 Setting per-category level
 
  LOG_CATEGORY_LEVEL (hash, json)
  LOG_CATEGORY_ALIAS (hash, json)
 
-Setting per-output, per-category level:
+=head2 Setting per-output, per-category level
 
  FILE_LOG_CATEGORY_LEVEL
  SCREEN_LOG_CATEGORY_LEVEL
  and so on
 
-Controlling extra fields to log:
+=head2 Controlling extra fields to log
 
  LOG_SHOW_LOCATION
  LOG_SHOW_CATEGORY
 
-Force-enable or disable color:
+=head2 Force-enable or disable color
 
  COLOR (bool)
 
-Turn on Log::Any::App's debugging:
+=head2 Turn on Log::Any::App's debugging
 
  LOGANYAPP_DEBUG (bool)
 
-Turn on showing elapsed time in screen:
+=head2 Turn on showing elapsed time in screen
 
  LOG_ELAPSED_TIME_IN_SCREEN (bool)
 
+=head2 Extra things to log
+
+=over
+
+=item * LOG_ENV (bool)
+
+If set to 1, will dump environment variables at the start of program. Useful for
+debugging e.g. CGI or git hook scripts. You might also want to look at
+L<Log::Any::Adapter::Core::Patch::UseDataDump> to make the dump more readable.
+
+Logging will be done under category C<main> and at level C<trace>.
+
+=back
+
 =head1 FAQ
 
 =head2 Why?
@@ -1816,4 +1836,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
